==> beast-0.5.0-rc1.tar.gz: beast-0.5.0-rc1/bse/bsecategories.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsecategories.proc"

#include <bse/bsecategories.h>
#include <bse/bseprocedure.h>
#include <bse/bseplugin.h>


#line 25 "bsecategories.proc"


/* --- bse-categories-match-typed --- */
static GType type_id_bse_categories_match_typed = 0;
static void
bse_categories_match_typed_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsecategories.proc"
 {
#line 29 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_DEFAULT);
  *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Base type for categories to conform to.",
			    NULL, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
}
#line 28 "bsecategories.proc"
  proc->help = "List BSE categories according to a pattern and type match.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 35 "bsecategories.proc"
 }
static BseErrorType
#line 35 "bsecategories.proc"
bse_categories_match_typed_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 38 "bsecategories.proc"
{
#line 39 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType  type      = type_name ? g_type_from_name (type_name) : 0;
  BseCategorySeq *cseq = NULL;
  
#line 45 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  if (type)
    cseq = bse_categories_match_typed (pattern, type);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 54 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- bse-categories-match --- */
static GType type_id_bse_categories_match = 0;
static void
bse_categories_match_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 60 "bsecategories.proc"
 {
#line 62 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
}
#line 61 "bsecategories.proc"
  proc->help = "List BSE categories according to a pattern match.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 66 "bsecategories.proc"
 }
static BseErrorType
#line 66 "bsecategories.proc"
bse_categories_match_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 69 "bsecategories.proc"
{
#line 70 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  BseCategorySeq *cseq = NULL;
  
#line 74 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  cseq = bse_categories_match (pattern);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 82 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- bse-category-from-id --- */
static GType type_id_bse_category_from_id = 0;
static void
bse_category_from_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 88 "bsecategories.proc"
 {
#line 90 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_int ("category_id", "Category ID", NULL,
			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("category", "Category", NULL, BSE_TYPE_CATEGORY, SFI_PARAM_DEFAULT);
}
#line 89 "bsecategories.proc"
  proc->help = "Find a BSE category from it's unique ID.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 94 "bsecategories.proc"
 }
static BseErrorType
#line 94 "bsecategories.proc"
bse_category_from_id_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 97 "bsecategories.proc"
{
#line 98 "bsecategories.proc"
  
  guint id = sfi_value_get_int (in_values++);
  BseCategory *cat;

  cat = bse_category_from_id (id);
  
#line 104 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cat);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
BSE_EXPORT_PROCEDURES = {
  { &type_id_bse_categories_match_typed, "bse-categories-match-typed", NULL, 0, bse_categories_match_typed_setup, bse_categories_match_typed_exec, NULL, "/Proc/Utils/Categories/Match Typed", { 0, }, },
  { &type_id_bse_categories_match, "bse-categories-match", NULL, 0, bse_categories_match_setup, bse_categories_match_exec, NULL, "/Proc/Utils/Categories/Match", { 0, }, },
  { &type_id_bse_category_from_id, "bse-category-from-id", NULL, 0, bse_category_from_id_setup, bse_category_from_id_exec, NULL, "/Proc/Utils/Categories/From ID", { 0, }, },
  { NULL, },
};
BSE_EXPORTS_END;

/**
 ** Generated data ends here
 **/

==> beast-0.5.2-rc1.tar.gz: beast-0.5.2-rc1/bse/bsecategories.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsecategories.proc"

#include <bse/bsecategories.h>
#include <bse/bseprocedure.h>
#include <bse/bseplugin.h>


#line 25 "bsecategories.proc"


/* --- bse-categories-match-typed --- */
static GType type_id_bse_categories_match_typed = 0;
static void
bse_categories_match_typed_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsecategories.proc"
 {
#line 29 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_DEFAULT);
  *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Base type for categories to conform to.",
			    NULL, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
}
#line 28 "bsecategories.proc"
  proc->help = "List BSE categories according to a pattern and type match.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 35 "bsecategories.proc"
 }
static BseErrorType
#line 35 "bsecategories.proc"
bse_categories_match_typed_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 38 "bsecategories.proc"
{
#line 39 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType  type      = type_name ? g_type_from_name (type_name) : 0;
  BseCategorySeq *cseq = NULL;
  
#line 45 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  if (type)
    cseq = bse_categories_match_typed (pattern, type);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 54 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- bse-categories-match --- */
static GType type_id_bse_categories_match = 0;
static void
bse_categories_match_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 60 "bsecategories.proc"
 {
#line 62 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
}
#line 61 "bsecategories.proc"
  proc->help = "List BSE categories according to a pattern match.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 66 "bsecategories.proc"
 }
static BseErrorType
#line 66 "bsecategories.proc"
bse_categories_match_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 69 "bsecategories.proc"
{
#line 70 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  BseCategorySeq *cseq = NULL;
  
#line 74 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  cseq = bse_categories_match_typed (pattern, 0);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 82 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- bse-category-from-id --- */
static GType type_id_bse_category_from_id = 0;
static void
bse_category_from_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 88 "bsecategories.proc"
 {
#line 90 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_int ("category_id", "Category ID", NULL,
			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("category", "Category", NULL, BSE_TYPE_CATEGORY, SFI_PARAM_DEFAULT);
}
#line 89 "bsecategories.proc"
  proc->help = "Find a BSE category from it's unique ID.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 94 "bsecategories.proc"
 }
static BseErrorType
#line 94 "bsecategories.proc"
bse_category_from_id_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 97 "bsecategories.proc"
{
#line 98 "bsecategories.proc"
  
  guint id = sfi_value_get_int (in_values++);
  BseCategory *cat;

  cat = bse_category_from_id (id);
  
#line 104 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cat);
  
  return BSE_ERROR_NONE;
}

static gboolean
categories_check_method (BseCategory *cat,
                         gpointer     data)
{
  GType *type_p = data;
  GType ptype = g_type_from_name (cat->type);
  gboolean match = FALSE;
  if (BSE_TYPE_IS_PROCEDURE (ptype))
    {
      BseProcedureClass *proc = g_type_class_ref (ptype);
      if (proc->n_in_pspecs >= 1 &&
          g_type_is_a (G_PARAM_SPEC_VALUE_TYPE (proc->in_pspecs[0]), *type_p))
        match = TRUE;
      g_type_class_unref (proc);
      if (match==TRUE)
        g_print ("method: %s\n", cat->type);
    }
  return match;
}

/* --- bse-categories-match-method --- */
static GType type_id_bse_categories_match_method = 0;
static void
bse_categories_match_method_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 130 "bsecategories.proc"
 {
#line 132 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_DEFAULT);
  *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Object base type for methods to conform to.",
			    NULL, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
}
#line 131 "bsecategories.proc"
  proc->help = "List BSE categories according to a pattern, of type procedure and applying to a certain object type.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 138 "bsecategories.proc"
 }
static BseErrorType
#line 138 "bsecategories.proc"
bse_categories_match_method_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 141 "bsecategories.proc"
{
#line 142 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType  type      = type_name ? g_type_from_name (type_name) : 0;
  BseCategorySeq *cseq = NULL;
  
#line 148 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  cseq = bse_categories_match (pattern, BSE_TYPE_PROCEDURE, categories_check_method, &type);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 156 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
BSE_EXPORT_PROCEDURES = {
  { &type_id_bse_categories_match_typed, "bse-categories-match-typed", NULL, 0, bse_categories_match_typed_setup, bse_categories_match_typed_exec, NULL, "/Proc/Utils/Categories/Match Typed", { 0, }, },
  { &type_id_bse_categories_match, "bse-categories-match", NULL, 0, bse_categories_match_setup, bse_categories_match_exec, NULL, "/Proc/Utils/Categories/Match", { 0, }, },
  { &type_id_bse_category_from_id, "bse-category-from-id", NULL, 0, bse_category_from_id_setup, bse_category_from_id_exec, NULL, "/Proc/Utils/Categories/From ID", { 0, }, },
  { &type_id_bse_categories_match_method, "bse-categories-match-method", NULL, 0, bse_categories_match_method_setup, bse_categories_match_method_exec, NULL, "/Proc/Utils/Categories/Match Method", { 0, }, },
  { NULL, },
};
BSE_EXPORTS_END;

/**
 ** Generated data ends here
 **/
